==> james-project-3.7.3-source-release.zip: james-project/server/apps/distributed-app/src/test/java/org/apache/james/WithCacheMutableTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james;

import org.junit.jupiter.api.extension.RegisterExtension;

class WithCacheMutableTest implements MailsShouldBeWellReceived {
    @RegisterExtension
    static JamesServerExtension jamesServerExtension = WithCacheImmutableTest.baseExtensionBuilder()
        .lifeCycle(JamesServerExtension.Lifecycle.PER_TEST)
        .build();
}

==> james-project-3.8.0-source-release.zip: james-project/server/apps/distributed-app/src/test/java/org/apache/james/WithCacheMutableTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james;

import org.junit.jupiter.api.extension.RegisterExtension;

class WithCacheMutableTest implements MailsShouldBeWellReceivedConcreteContract {
    @RegisterExtension
    static JamesServerExtension jamesServerExtension = WithCacheImmutableTest.baseExtensionBuilder()
        .lifeCycle(JamesServerExtension.Lifecycle.PER_TEST)
        .build();
}
